import pip
pip.main(['install', 'msvc-runtime'])

from potatohelper import HandTrackingModule
from potatohelper import FingerCounter
from potatohelper import FaceDetection
from potatohelper import FaceMesh
		
